@@ -4,6 +4,8 @@ import argparse
 import ipaddress
 import socket
 
+from jfscripts import __version__
+
 
 def get_ipv6(dns_name):
     result = socket.getaddrinfo(dns_name, port=None)
@@ -25,22 +27,38 @@ def get_ipv6(dns_name):
             return entry[4][0]
 
 
-def main():
-    parser = argparse.ArgumentParser(
-        description='Get the ipv6 prefix from a DNS name.'
-    )
+def get_parser():
+    """The argument parser for the command line interface.
+
+    :return: A ArgumentParser object.
+    :rtype: argparse.ArgumentParser
+    """
+    parser = argparse.ArgumentParser(description="Get the ipv6 prefix from a DNS name.")
+
     parser.add_argument(
-        'dnsname',
-        help='The DNS name, e. g. josef-friedrich.de',
+        "dnsname",
+        help="The DNS name, e. g. josef-friedrich.de",
     )
 
-    args = parser.parse_args()
+    parser.add_argument(
+        "-V",
+        "--version",
+        action="version",
+        version="%(prog)s {version}".format(version=__version__),
+    )
+
+    return parser
+
+
+def main():
+    args = get_parser().parse_args()
+
     ipv6 = get_ipv6(args.dnsname)
 
-    prefix = ipaddress.ip_network(ipv6 + '/64', strict=False)
+    prefix = ipaddress.ip_network(ipv6 + "/64", strict=False)
 
     print(prefix)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
