@@ -3,6 +3,8 @@
 import argparse
 import os
 
+from jfscripts import __version__
+
 
 def check_for_duplicates(path):
     print(path)
@@ -25,25 +27,43 @@ def check_for_duplicates(path):
             duplicate_paths[full_paths[0]] = full_paths
 
     for key, full_paths in sorted(duplicate_paths.items()):
-        print('-----------------------------------------')
+        print("-----------------------------------------")
         for full_path in full_paths:
             print('rm -f "' + full_path + '"')
 
-    print('Duplicates found: ' + str(count))
+    print("Duplicates found: " + str(count))
+
+
+def get_parser():
+    """The argument parser for the command line interface.
+
+    :return: A ArgumentParser object.
+    :rtype: argparse.ArgumentParser
+    """
+    parser = argparse.ArgumentParser(
+        description="Find duplicate files by size.",
+    )
+
+    parser.add_argument(
+        "path",
+        help="A directory to recursively search for duplicate files.",
+    )
+
+    parser.add_argument(
+        "-V",
+        "--version",
+        action="version",
+        version="%(prog)s {version}".format(version=__version__),
+    )
+
+    return parser
 
 
 def main():
-    parser = argparse.ArgumentParser(
-        description='Find duplicate files by size.',
-    )
-    parser.add_argument(
-        'path',
-        help='A directory to recursively search for duplicate files.',
-    )
-    args = parser.parse_args()
+    args = get_parser().parse_args()
 
     check_for_duplicates(args.path)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
